﻿using AutoMapper;
using MediatR;
using NetworkResurrector.Api.Domain.Repositories;
using System.Threading;
using System.Threading.Tasks;

namespace NetworkResurrector.Api.Application.Queries
{
    public class GetMachines
    {
        public class Query : IRequest<Model[]> { }

        public class Model
        {
            public int MachineId { get; set; }
            public string MachineName { get; set; }
            public string FullMachineName { get; set; }
            public string MACAddress { get; set; }
            public string IPv4Address { get; set; }
            public string Description { get; set; }
        }

        public class QueryHandler : IRequestHandler<Query, Model[]>
        {
            private readonly INetworkRepository _repository;
            private readonly IMapper _mapper;

            public QueryHandler(INetworkRepository repository, IMapper mapper)
            {
                _repository = repository;
                _mapper = mapper;
            }

            public async Task<Model[]> Handle(Query request, CancellationToken cancellationToken)
            {
                var machines = await _repository.GetMachines();
                var result = _mapper.Map<Model[]>(machines);

                return result;
            }
        }
    }
}
